
.. _iv:

==============================
Independent variable dimension
==============================

.. In the `csdmpy` package, the  :ref:`CSDM_api` class is not just designed
.. to read and save a scientific data file.

Based on the type of coordinates and the spacing between the coordinates of
an independent variable dimension, the instance of the :ref:`dim_api` class
are classifies as one of the following:

.. toctree::
    :maxdepth: 1

    independentVariable/linear
